PERIODSDATA = [
    {
        "broader": [1234],
        "id": 10,
        "labels": [
            {"label": "10de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "10", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1019, 1020],
        "notes": [{"language": "nl", "note": "901-1000", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1234],
        "id": 11,
        "labels": [
            {"label": "11de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "11", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1021, 1022],
        "notes": [{"language": "nl", "note": "1001-1100", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1234],
        "id": 12,
        "labels": [
            {"label": "12de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "12", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1023, 1024],
        "notes": [{"language": "nl", "note": "1101-1200", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1235],
        "id": 13,
        "labels": [
            {"label": "13de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "13", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1025, 1028],
        "notes": [{"language": "nl", "note": "1201-1300", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1235],
        "id": 14,
        "labels": [
            {"label": "14de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "14", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1031, 1034],
        "notes": [{"language": "nl", "note": "1301-1400", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1235],
        "id": 15,
        "labels": [
            {"label": "15de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "15", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1037, 1040],
        "notes": [{"language": "nl", "note": "1401-1500", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1236],
        "id": 16,
        "labels": [
            {"label": "16de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "16", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1043, 1046],
        "notes": [{"language": "nl", "note": "1501-1600", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1236],
        "id": 17,
        "labels": [
            {"label": "17de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "17", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1049, 1052],
        "notes": [{"language": "nl", "note": "1601-1700", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1236],
        "id": 18,
        "labels": [
            {"label": "18de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "18", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1055, 1058],
        "notes": [{"language": "nl", "note": "1701-1800", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1237],
        "id": 19,
        "labels": [
            {"label": "19de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "19", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1061, 1064],
        "notes": [{"language": "nl", "note": "1801-1900", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1237],
        "id": 20,
        "labels": [
            {"label": "20ste eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "20", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1067, 1072],
        "notes": [{"language": "nl", "note": "1901-2000", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1237],
        "id": 21,
        "labels": [
            {"label": "21ste eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "21", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1075, 1078],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1233],
        "id": 8,
        "labels": [
            {"label": "8ste eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "8", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1015, 1016],
        "notes": [{"language": "nl", "note": "700/710-800", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1233],
        "id": 9,
        "labels": [
            {"label": "9de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "9", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1017, 1018],
        "notes": [{"language": "nl", "note": "801-900", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1292],
        "id": 1293,
        "labels": [{"label": "atlanticum", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "8000 tot 5000 jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [1209],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1273],
        "id": 1279,
        "labels": [{"label": "baveliaan", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "1,1 miljoen jaar geleden tot 850.000 jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1289],
        "id": 1291,
        "labels": [{"label": "boreaal", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "9000 tot 8000 jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [1204],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1196],
        "id": 1197,
        "labels": [{"label": "bronstijd", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1198, 1214, 1217],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Deze periode (2000 - 800 v.Chr.) kenmerkt zich door het"
                    " wijdverbreide gebruik van brons, een legering van koper en tin,"
                    " lood, antimonium of arsenicum bij de vervaardiging van"
                    " gereedschappen en wapens. De bronstijd ontwikkelde zich op"
                    " verschillende momenten in verschillende delen van de wereld,"
                    " vanaf circa 3500 v. Chr. in Griekenland en China en vanaf circa"
                    " 2000 v.Chr. in verschillende delen van Europa."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                    " \n2) 4. Bronstijd/ijzertijd, in: Onderzoeksbalans Onroerend"
                    " Erfgoed Vlaanderen <a"
                    ' href="https://www.onderzoeksbalans.be/">https://www.onderzoeksbalans.be/</a>'
                    " \n3) Van Dale groot woordenboek der Nederlandse taal."
                ),
                "type": "note",
            },
        ],
        "related": [1296],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1252],
        "id": 1253,
        "labels": [{"label": "cambrium", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "546 tot 495 miljoen jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1252],
        "id": 1257,
        "labels": [{"label": "carboon", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "354 tot 298 miljoen jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1280],
        "id": 1281,
        "labels": [{"label": "cromeriaan", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "850.000 tot 475.000 jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1028],
        "id": 1029,
        "labels": [
            {"label": "derde kwart 13de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "13c", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1251-1275", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1034],
        "id": 1035,
        "labels": [
            {"label": "derde kwart 14de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "14c", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1351-1375", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1040],
        "id": 1041,
        "labels": [
            {"label": "derde kwart 15de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "15c", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1451-1475", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1046],
        "id": 1047,
        "labels": [
            {"label": "derde kwart 16de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "16c", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1551-1575", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1052],
        "id": 1053,
        "labels": [
            {"label": "derde kwart 17de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "17c", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1651-1675", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1058],
        "id": 1059,
        "labels": [
            {"label": "derde kwart 18de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "18c", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1751-1775", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1064],
        "id": 1065,
        "labels": [
            {"label": "derde kwart 19de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "19c", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1851-1875", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1078],
        "id": 1079,
        "labels": [
            {"label": "derde kwart 21ste eeuw", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "2051-2075", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1252],
        "id": 1256,
        "labels": [{"label": "devoon", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "410 tot 354 miljoen jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1273],
        "id": 1276,
        "labels": [{"label": "eburoniaan", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "1,8 tot 1,5 miljoen jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1285],
        "id": 1286,
        "labels": [{"label": "eemiaan", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "130.000 tot 115.000 jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [10],
        "id": 1019,
        "labels": [
            {"label": "eerste helft 10de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "10ab", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "901-950", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [11],
        "id": 1021,
        "labels": [
            {"label": "eerste helft 11de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "11ab", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1001-1050", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [12],
        "id": 1023,
        "labels": [
            {"label": "eerste helft 12de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "12ab", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1101-1150", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [13],
        "id": 1025,
        "labels": [
            {"label": "eerste helft 13de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "13ab", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1026, 1027],
        "notes": [{"language": "nl", "note": "1201-1250", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [14],
        "id": 1031,
        "labels": [
            {"label": "eerste helft 14de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "14ab", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1032, 1033],
        "notes": [{"language": "nl", "note": "1301-1350", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [15],
        "id": 1037,
        "labels": [
            {"label": "eerste helft 15de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "15ab", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1038, 1039],
        "notes": [{"language": "nl", "note": "1401-1450", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [16],
        "id": 1043,
        "labels": [
            {"label": "eerste helft 16de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "16ab", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1044, 1045],
        "notes": [{"language": "nl", "note": "1501-1550", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [17],
        "id": 1049,
        "labels": [
            {"label": "eerste helft 17de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "17ab", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1050, 1051],
        "notes": [{"language": "nl", "note": "1601-1650", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [18],
        "id": 1055,
        "labels": [
            {"label": "eerste helft 18de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "18ab", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1056, 1057],
        "notes": [{"language": "nl", "note": "1701-1750", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [19],
        "id": 1061,
        "labels": [
            {"label": "eerste helft 19de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "19ab", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1062, 1063],
        "notes": [{"language": "nl", "note": "1801-1850", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [20],
        "id": 1067,
        "labels": [
            {"label": "eerste helft 20ste eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "20ab", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1068, 1069, 1070, 1071],
        "notes": [{"language": "nl", "note": "1901-1945", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [21],
        "id": 1075,
        "labels": [
            {"label": "eerste helft 21ste eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "21ab", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1076, 1077],
        "notes": [{"language": "nl", "note": "2001-2050", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [8],
        "id": 1015,
        "labels": [
            {"label": "eerste helft 8ste eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "8ab", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "700/710-750", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [9],
        "id": 1017,
        "labels": [
            {"label": "eerste helft 9de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "9ab", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "801-850", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1025],
        "id": 1026,
        "labels": [
            {"label": "eerste kwart 13de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "13a", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1201-1225", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1031],
        "id": 1032,
        "labels": [
            {"label": "eerste kwart 14de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "14a", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1301-1325", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1037],
        "id": 1038,
        "labels": [
            {"label": "eerste kwart 15de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "15a", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1401-1425", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1043],
        "id": 1044,
        "labels": [
            {"label": "eerste kwart 16de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "16a", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1501-1525", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1049],
        "id": 1050,
        "labels": [
            {"label": "eerste kwart 17de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "17a", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1601-1625", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1055],
        "id": 1056,
        "labels": [
            {"label": "eerste kwart 18de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "18a", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1701-1725", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1061],
        "id": 1062,
        "labels": [
            {"label": "eerste kwart 19de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "19a", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1801-1825", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1075],
        "id": 1076,
        "labels": [
            {"label": "eerste kwart 21ste eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "21a", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "2001-2025", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1280],
        "id": 1282,
        "labels": [{"label": "elsteriaan", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "475.000 tot 410.000 jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1264],
        "id": 1266,
        "labels": [{"label": "eoceen", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "53 tot 33,7 miljoen jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1204],
        "id": 1208,
        "labels": [
            {"label": "finaalmesolithicum", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Men neemt aan dat in deze periode boeren (neolithicum) en"
                    " jagers-verzamelaars (mesolithicum) naast elkaar leven. Over de"
                    " aard van de relatie tussen beide groepen is echter nog veel"
                    " onduidelijkheid. Deze finale fase van het mesolithicum kan"
                    " gedateerd worden tussen ca. 5000 en ca. 4000 v.Chr."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Louwe Kooijmans L., van den Broecke P.W., Fokkens H. en van Gijn"
                    " A. (eds.), 2005, Nederland in de prehistorie, Amsterdam."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1209],
        "id": 1213,
        "labels": [
            {"label": "finaalneolithicum", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Te dateren tussen 3000 en 2000 v.Chr. In het finaalneolithicum"
                    " zien we dat de culturele verschillen tussen ZO-Europa enerzijds"
                    " en NW- en Centraal-Europa anderzijds steeds groter worden. In het"
                    " eerstgenoemde gebied ontwikkelt de bronstijd zich reeds volop. In"
                    " meer noordelijke en westelijke regio\u2019s zien we eerder een"
                    " continu\xefteit met het middenneolithicum, al doen zich ook daar"
                    " belangrijke veranderingen voor die de bronstijd inluiden. De"
                    " culturele samenstelling wordt nog complexer. De versterkte"
                    " nederzettingen van het middenneolithicum worden minder frequent."
                    " De megalithische traditie uit het middenneolithicum zet zich"
                    " voort (evolutie naar galerijgraven; henge-monumenten op de Britse"
                    " eilanden)."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": "cursusmateriaal UGent (Prof. Ph. Cromb\xe9)",
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1199],
        "id": 1203,
        "labels": [
            {"label": "finaalpaleolithicum", "language": "nl", "type": "prefLabel"},
            {"label": "epipaleolithicum", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Het finaalpaleolithicum komt grosso modo overeen met het tweede"
                    " deel van het laatglaciaal en kan gedateerd worden tussen 12000 en"
                    " 9500 BP (14 000 - 12 000 jaar geleden). Het kan beschouwd worden"
                    " als een voortzetting van het laatpaleolithicum. De culturen die"
                    " met deze periode geassocieerd worden zijn de Federmessercultuur"
                    " en het Ahrensburgiaan. Tijdens deze periode kent men de eerste"
                    " massale menselijke aanwezigheid op het huidige Vlaamse"
                    " grondgebied."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "VIOE", "type": "note"},
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "id": 1251,
        "labels": [
            {"label": "geologische dateringen", "language": "nl", "type": "prefLabel"}
        ],
        "member_of": [],
        "members": [1252, 1259, 1263, 1271],
        "notes": [],
        "superordinates": [],
        "type": "collection",
    },
    {
        "broader": [1271],
        "id": 1288,
        "labels": [{"label": "holoceen", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1289, 1292, 1295],
        "notes": [
            {
                "language": "nl",
                "note": "10.000 jaar geleden tot heden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1280],
        "id": 1283,
        "labels": [{"label": "holsteiniaan", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "410.000 tot 370.000 jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1196],
        "id": 1218,
        "labels": [{"label": "ijzertijd", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1219, 1220, 1221, 1222],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "De ijzertijd ontstond wanneer het belang van ijzer toenam bij de"
                    " vervaardiging van gereedschappen, wapens en werktuigen en daarbij"
                    " brons verdrong. De ijzertijd kwam op verschillende tijdstippen in"
                    " verschillende delen van de wereld tot ontwikkeling, eerst in het"
                    " Midden-Oosten en Zuidoost-Europa rond 1200 v. Chr. en rond 750"
                    " v.Chr. in Noordwest-Europa. Het einde van de ijzertijd kan in"
                    " onze regio's vastgelegd worden met de komst van de Romeinen: 57"
                    " v.Chr."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                    " \n2) Van Dale groot woordenboek der Nederlandse taal \n3)"
                    " Cursusmateriaal UGent (Prof. J. Bourgeois) \n4) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [1296],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1067],
        "id": 1070,
        "labels": [{"label": "interbellum", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1919-1938", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1259],
        "id": 1261,
        "labels": [{"label": "jura", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "203 tot 144 miljoen jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1228],
        "id": 1233,
        "labels": [
            {"label": "Karolingische periode", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [8, 9],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "De Karolingische periode verwijst naar de periode en stijl rond de"
                    " regeerperiode van Karel de Grote (768-814) en zijn opvolgers tot"
                    " circa 900 n.Chr. De stijl kenmerkt zich door een vernieuwing van"
                    " de cultuur van het Romeinse Rijk zoals dat bestond onder de"
                    " keizers Constantijn en Theodosius."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Van Dale groot woordenboek der Nederlandse taal. 14de editie,"
                    " Utrecht/Antwerpen, 2005. \n2) Nederlandse Art &amp; Architecture"
                    " Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                    " \n3) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1259],
        "id": 1262,
        "labels": [{"label": "krijt", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "144 tot 65 miljoen jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1288],
        "id": 1295,
        "labels": [{"label": "laatholoceen", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1296],
        "notes": [
            {"language": "nl", "note": "2600 tot heden", "type": "definition"},
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1229],
        "id": 1232,
        "labels": [
            {
                "label": "laat-Merovingische periode",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "De laat-Merovingische periode is te dateren van 600/610 tot"
                    " 700/710."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Legoux R., P\xe9rin P. &amp; Vallet F. 2006: Chronologie"
                    " normalis\xe9e du mobilier fun\xe9raire m\xe9rovingien entre"
                    " Manche et Lorraine, in: Bulletin de Liaison de l'Association"
                    " fran\xe7aise d'Arch\xe9ologie m\xe9rovingienne. N\xb0 hors"
                    " s\xe9rie, St. Germain-en-Laye (bijgewerkte versie van 2004)."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1204],
        "id": 1207,
        "labels": [
            {"label": "laatmesolithicum", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Het laatmesolithicum kan gedateerd worden tussen 7000/6500 en 5000"
                    " v.Chr. Aan het einde van deze periode (ca. 5300 v.Chr.) beginnen"
                    " de eerste boeren in de l\xf6ss-streken van Zuid-Nederland, het"
                    " Rijnland en delen van Belgi\xeb te arriveren (Lineaire"
                    " Bandkeramiek)."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Louwe Kooijmans L., van den Broecke P.W., Fokkens H. en van Gijn"
                    " A. (eds.), 2005, Nederland in de prehistorie, Amsterdam."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1209],
        "id": 1212,
        "labels": [{"label": "laatneolithicum", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "3500-3000 v.Chr.", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1199],
        "id": 1202,
        "labels": [
            {"label": "laatpaleolithicum", "language": "nl", "type": "prefLabel"},
            {"label": "jongpaleolithicum", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Te dateren tussen 40 000 en 14 000 jaar geleden. Verwijst naar de"
                    " laatste fase van de paleolithische periode, met name in Europa,"
                    " waar de fase zich kenmerkt door ingrijpende culturele"
                    " veranderingen, veroorzaakt door verandering van klimaat, flora en"
                    " fauna. In deze periode doet de Homo Sapiens zijn intrede."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                    " \n2) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1272],
        "id": 1285,
        "labels": [{"label": "laatpleistoceen", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1286, 1287],
        "notes": [
            {
                "language": "nl",
                "note": "130.000 tot 10.000 jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1223],
        "id": 1226,
        "labels": [
            {"label": "Laat-Romeinse Tijd", "language": "nl", "type": "prefLabel"},
            {"label": "late keizertijd", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "284-406. Deze periode komt aan zijn einde op het moment dat de"
                    " Goten voor de poorten van Rome staan en Galli\xeb overspoeld"
                    " wordt door Germaanse stammen."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "VIOE", "type": "note"},
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1197],
        "id": 1217,
        "labels": [{"label": "late bronstijd", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Verwijst naar de laatste fase van de bronstijd (1100 - 800"
                    " v.Chr.), die verschillen van de vroege en de middenbronstijd door"
                    " afwijkende samenstellingen van metalen voorwerpen en afwijkende"
                    " begrafenisrituelen. Kenmerkend zijn de geavanceerde en verfijnde"
                    " metaalbewerkingstechnieken en ontwerpen van gereedschappen en"
                    " wapens. Dit geldt tevens voor de ontwikkeling van op grote schaal"
                    " geproduceerde objecten, holle voorwerpen, wapenrustingen en grote"
                    " voorwerpen, zoals ketels en schilden. Bij het grafritueel is een"
                    " duidelijke overgang merkbaar van inhumatie naar crematie"
                    " (urnengraven). Rivierdeposities zijn typisch voor deze periode"
                    " (bronzen voorwerpen (offensieve en defensieve wapens, sieraden en"
                    " gebruiksvoorwerpen) werden intentioneel in het water gegooid)."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Cursusmateriaal UGent (Prof. J. Bourgeois) \n2) Nederlandse Art"
                    " &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1218],
        "id": 1221,
        "labels": [{"label": "late ijzertijd", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Verwijst naar een fase in de ijzertijd (250 - 57 v.Chr.) die"
                    " opvalt door de specifieke sociale en technologische"
                    " ontwikkelingen. In het Scheldegebied wordt het begin van de late"
                    " ijzertijd gekenmerkt door invloeden vanuit Noord-Frankrijk. Het"
                    " gebied wordt cultureel be\xefnvloed door de Marnestreek. Deze"
                    " culturele dominantie vertolkte zich vooral in de materi\xeble"
                    " cultuur en meer specifiek in het aardewerk. In deze periode"
                    " duiken bovendien nieuwe elite-groepen op die contacten"
                    " onderhouden met verwante machtgroepen in het Keltische gebied in"
                    " Centraal-Europa (uitwisseling van prestigegoederen). Het einde"
                    " van de ijzertijd wordt traditioneel gelijkgeschakeld met de komst"
                    " van de Romeinen onder leiding van Caesar in de jaren 50 van de"
                    " laatste eeuw v.Chr. Ten oosten van de Schelde wordt een opdeling"
                    " gemaakt voor de ijzertijd in 3 eenheden, nl. vroege ijzertijd,"
                    " middenijzertijd en late ijzertijd."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                    " \n2) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1218],
        "id": 1222,
        "labels": [{"label": "late ijzertijd", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Verwijst naar een fase in de ijzertijd (475/450 - 57 v.Chr.) die"
                    " opvalt door de specifieke sociale en technologische"
                    " ontwikkelingen. In het Scheldegebied wordt het begin van de late"
                    " ijzertijd gekenmerkt door invloeden vanuit Noord-Frankrijk. Het"
                    " gebied wordt cultureel be\xefnvloed door de Marnestreek. Deze"
                    " culturele dominantie vertolkte zich vooral in de materi\xeble"
                    " cultuur en meer specifiek in het aardewerk. In deze periode"
                    " duiken bovendien nieuwe elite-groepen op die contacten"
                    " onderhouden met verwante machtgroepen in het Keltische gebied in"
                    " Centraal-Europa (uitwisseling van prestigegoederen). Het einde"
                    " van de ijzertijd wordt traditioneel gelijkgeschakeld met de komst"
                    " van de Romeinen onder leiding van Caesar in de jaren 50 van de"
                    " laatste eeuw v.Chr. Ten westen van de Schelde maakt men geen"
                    " onderverdeling naar middenijzertijd; men gebruikt er naast vroege"
                    " ijzertijd enkel late ijzertijd."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                    " \n2) Bourgeois J., Cromb\xe9 P., De Mulder G. &amp; Rogge M."
                    " (red.), 2001, Een duik in het verleden. Schelde Maas en Rijn in"
                    " pre- en protohistorie, Zottegem. \n3) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1227],
        "id": 1235,
        "labels": [
            {"label": "late middeleeuwen", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [13, 14, 15],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Te gebruiken met betrekking tot de periode van ca. 1200 tot 1500."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                    " \n2) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1273],
        "id": 1278,
        "labels": [{"label": "menapiaan", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "1,2 tot 1,1 miljoen jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1228],
        "id": 1229,
        "labels": [
            {"label": "Merovingische periode", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1230, 1231, 1232],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "De Merovingische periode verwijst naar de periode en stijl die"
                    " werd ingeluid door de verovering van Galli\xeb in 486 door Clovis"
                    " van de Merovingische dynastie. De stijl kenmerkt zich in de"
                    " architectuur door het gebruik, hoewel spaarzaam en in"
                    " vereenvoudigde vorm, van de vroegere laat-antieke en"
                    " vroegchristelijke stijlen, waarbij de nadruk vaak lag op"
                    " decoratieve effecten en geometrische patronen. De Frankische"
                    " periode wordt niet langer als een opdeling voor de vroege"
                    " middeleeuwen gezien, maar als onderdeel van de Merovingische"
                    " periode. De 'Frankische periode' verwijst naar de periode en"
                    " stijl van de Franken, een Germaanse stam die in ieder geval vanaf"
                    " de 3de eeuw n. Chr. langs de oostelijke oever van de benedenloop"
                    " van de Rijn leefde. De stijl wordt in het bijzonder geassocieerd"
                    " met de expansie van de Franken in westelijke richting aan de"
                    " overkant van de Rijn, in Galli\xeb, door geleidelijke kolonisatie"
                    " en verovering, met name onder leiding van de Merovingische koning"
                    " Clovis. Deze expansie begon in de 5de eeuw en heeft eeuwen"
                    " geduurd. Naast de Franken hebben ook de Saksen, een Germaanse"
                    " stam afkomstig uit Noord-Europa (Duitsland en een deel van"
                    " Nederland), hun sporen in ons land achtergelaten."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                    " \n2) Van Dale groot woordenboek der Nederlandse taal. 14de"
                    " editie, Utrecht/Antwerpen, 2005. \n3) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1195],
        "id": 1204,
        "labels": [
            {"label": "mesolithicum", "language": "nl", "type": "prefLabel"},
            {"label": "middensteentijd", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1205, 1206, 1207, 1208],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Verwijst meestal specifiek naar een periode van culturele"
                    " ontwikkeling in Europa die ca. 9000 v.Chr. (10000 BP) begon, toen"
                    " de ijskap zich aan het eind van het pleistoceen begon terug te"
                    " trekken, en die voortduurde tot circa 4000 v. Chr. Volgens de"
                    " huidige opvattingen is er sprake van een continu\xefteit tussen"
                    " het laatpaleolithicum en het mesolithicum. De periode wordt"
                    " doorgaans gemarkeerd door de vervaardiging van microlieten die"
                    " bijvoorbeeld op pijlen en harpoenen werden geplaatst. De"
                    " artistieke producten die uit deze periode bewaard zijn gebleven"
                    " omvatten gravures en grotschilderingen met relatief verfijnde"
                    " afbeeldingen van menselijke en dierlijke voorstellingen."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                    " \n2) Van Dale groot woordenboek der Nederlandse taal. 14de"
                    " editie, Utrecht/Antwerpen, 2005. \n3) Louwe Kooijmans L., van den"
                    " Broecke P.W., Fokkens H. en van Gijn A. (eds.), 2005, Nederland"
                    " in de prehistorie, Amsterdam. \n4) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [1291],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 1259,
        "labels": [{"label": "mesozo\xefcum", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1251],
        "narrower": [1260, 1261, 1262],
        "notes": [
            {
                "language": "nl",
                "note": "251 tot 65 miljoen jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 1196,
        "labels": [
            {"label": "metaaltijden", "language": "nl", "type": "prefLabel"},
            {"label": "protohistorie", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1197, 1218],
        "notes": [],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 1227,
        "labels": [{"label": "middeleeuwen", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1228, 1234, 1235],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Verwijst naar de periode in West-Europa van grofweg de 5de tot de"
                    " 15de eeuw. De verschillende stijlen die zich tijdens deze periode"
                    " ontwikkelden kenmerken zich door de evolutie van de"
                    " Grieks-Romeinse traditie naar een meer christelijke thematiek,"
                    " door de energieke geest van de Germaanse volken en door de"
                    " bloeiende nieuwe steden die werden bevolkt door vrije burgers."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                    " \n2) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [1296],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1197],
        "id": 1214,
        "labels": [{"label": "middenbronstijd", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1215, 1216],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Verwijst naar een fase in de bronstijd (1800/1750 - 1100 v.Chr.)"
                    " die zich onderscheidt van de culturen van de vroege en late"
                    " bronstijd door de verschillen in metaalassemblages en"
                    " begrafenisrituelen. De fase kenmerkt zich deels door"
                    " metaalbewerkingstechnieken en steeds meer verfijnde ontwerpen van"
                    " werktuigen en wapens, bij de vervaardiging waarvan onder andere"
                    " gebruik werd gemaakt van afsluitbare gietvormen, het verloren"
                    " wasproc\xe9d\xe9, bewerking van platen, constructieribben,"
                    " krammen en degenknoppen aan het eind van het zwaardheft. Het"
                    " begin van deze fase wordt nu rond 1800 v.Chr. vastgelegd en wordt"
                    " gekenmerkt door het verschijnen van het zgn. Hilversum-aardewerk"
                    " in graven en nederzettingen en de aanleg van begraafplaatsen met"
                    " grote grafheuvels, al dan niet omgeven door een ringgracht of een"
                    " krans van houten palen, boomstammen eigenlijk."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                    " \n2) Van Dale groot woordenboek der Nederlandse taal. 14de"
                    " editie, Utrecht/Antwerpen, 2005. \n3) 4.1.3. Middenbronstijd, in:"
                    " Onderzoeksbalans Onroerend Erfgoed Vlaanderen <a"
                    ' href="https://www.onderzoeksbalans.be/">https://www.onderzoeksbalans.be/</a>'
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1214],
        "id": 1215,
        "labels": [
            {"label": "middenbronstijd A", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "De middenbronstijd A (1800 - 1500 v.Chr.) kenmerkt zich door het"
                    " verschijnen van grafheuvels met circulaire greppels en het"
                    " voorkomen van Hilversumaardewerk."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Fokkens H. 2001, The periodisation of the Dutch Bronze Age: a"
                    " critical review, in: W.Metz, van Beek B. &amp; Steegstra H."
                    " (eds.), Patina: essays presented to Jay Jordan Butler on the"
                    " occasion of his 80th birthday, pp. 241-262."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1214],
        "id": 1216,
        "labels": [
            {"label": "middenbronstijd B", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "De middenbronstijd B (1500 - 1100 v.Chr.) kenmerkt zich door het"
                    " voorkomen van grafheuvels met palenkransen."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Fokkens H. 2001, The periodisation of the Dutch Bronze Age: a"
                    " critical review, in: W.Metz, van Beek B. &amp; Steegstra H."
                    " (eds.), Patina: essays presented to Jay Jordan Butler on the"
                    " occasion of his 80th birthday, pp. 241-262."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1288],
        "id": 1292,
        "labels": [{"label": "middenholoceen", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1293, 1294],
        "notes": [
            {
                "language": "nl",
                "note": "8000 tot 2600 jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1218],
        "id": 1220,
        "labels": [{"label": "middenijzertijd", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Verwijst naar een fase in de ijzertijd die wordt gemarkeerd door"
                    " technologische en sociale ontwikkelingen, zoals carburisatie van"
                    " ijzer of staal. De Griekse koloniesteden in het westen van het"
                    " Middellandse Zeegebied nemen de belangrijkste rol overen gaan de"
                    " handelscircuits domineren via het westen van de Alpen. De"
                    " veranderende economische relaties brengen ook sociale"
                    " veranderingen met zich mee. Ten westen van de Alpen zal een"
                    " uitgesproken aristocratische samenleving tot stand komen die zich"
                    " uit in graven en nederzettingen. Men spreekt van Keltische"
                    " prinsen met Herrn- of Furstensitzes. Rond deze aristocratische"
                    " sites treft men rijke prinselijke graven aan (Furstengr\xe4ber)."
                    " Deze fase wordt gedateerd tussen 600 en 450 v.Chr. Ten oosten van"
                    " de Schelde wordt een opdeling gemaakt voor de ijzertijd in 3"
                    " eenheden, nl. vroege ijzertijd, middenijzertijd en late"
                    " ijzertijd. Ten oosten van de Schelde is de middenijzertijd"
                    " duidelijk te onderscheiden."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                    " \n2) Van Dale groot woordenboek der Nederlandse taal. 14de"
                    " editie, Utrecht/Antwerpen, 2005. \n3) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1204],
        "id": 1206,
        "labels": [
            {"label": "middenmesolithicum", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Het middenmesolithicum toont een grotere diversiteit aan"
                    " microliettypen, met name het optreden van segmenten en driehoeken"
                    " en spitsen met oppervlakteretouches. De periode kan gedateerd"
                    " worden tussen 7700 en 7000/6500 v.Chr."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Louwe Kooijmans L., van den Broecke P.W., Fokkens H. en van Gijn"
                    " A. (eds.), 2005, Nederland in de prehistorie, Amsterdam."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1209],
        "id": 1211,
        "labels": [
            {"label": "middenneolithicum", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Te dateren tussen 4300 en 3500 v.Chr. Na de eerste"
                    " neolithisatiegolf, die grotendeels beperkt bleef tot gebieden met"
                    " gronden die primitieve landbouw toelieten, zoals de loessgronden"
                    " van Centraal en West-Europa, volgt een tweede beweging waarin de"
                    " neolithische leefwijze zich verspreidt over de resterende"
                    " gebieden van Europa, zoals het Alpengebied en de Atlantische"
                    " kustzone van (N)W-Europa. Het middenneolithicum is de periode van"
                    " deze nieuwe golf van neolithisering, ook secundaire"
                    " neolithisering genoemd. Veruit het belangrijkste kenmerk van de"
                    " middenneolithische nederzettingen in Centraal- en NW-Europa is de"
                    " aanleg van imposante omheiningssystemen rond de meestal"
                    " uitgestrekte \u201cnederzettingen\u201d. Meestal bestaat de"
                    " omheining uit een of meerdere diepe grachten, gevolgd door aarden"
                    " wal(len) en palissade(s). E\xe9n van de meest typische kenmerken"
                    " van het midden-neolithicum in Europa is ongetwijfeld de mijnbouw,"
                    " naast de megalithische traditie. Een relatief nieuw technologisch"
                    " gegeven in de middenneolithische maatschappijen, zeker in"
                    " Noordwest-Europa, is het polijsten niet enkel van harde"
                    " gesteenten, maar voor het eerst ook van silex. Men gaat over van"
                    " tribale gemeenschappen naar chiefdom-gemeenschappen met o.a."
                    " sociale hi\xebrarchie."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": "cursusmateriaal UGent (Prof. Ph. Cromb\xe9)",
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1199],
        "id": 1201,
        "labels": [
            {"label": "middenpaleolithicum", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Verwijst in het algemeen naar een periode tussen de"
                    " vroegpaleolithische en de laatpaleolithische tijd, te dateren"
                    " tussen 300.000/250.000 tot 40.000/30.000 jaar geleden in Europa."
                    " Tijdens deze periode werden de culturen gekenmerkt door een"
                    " nieuwe afslagtechniek (Levallois), hoewel ook de oudere"
                    " vuistbijltraditie behouden bleef. Het is ook de periode van de"
                    " Neaderthalers."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                    " \n2) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1272],
        "id": 1280,
        "labels": [
            {"label": "middenpleistoceen", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1281, 1282, 1283, 1284],
        "notes": [
            {
                "language": "nl",
                "note": "850.000 tot 130.000 jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1223],
        "id": 1225,
        "labels": [
            {"label": "Midden-Romeinse tijd", "language": "nl", "type": "prefLabel"},
            {"label": "midden-keizertijd", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "Te dateren tussen 69 en 284.",
                "type": "definition",
            },
            {"language": "nl", "note": "VIOE", "type": "note"},
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1268],
        "id": 1269,
        "labels": [{"label": "mioceen", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "23,8 tot 5,3 miljoen jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1072],
        "id": 1073,
        "labels": [{"label": "na WO II", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1946-1974", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1263],
        "id": 1268,
        "labels": [{"label": "neogeen", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1269, 1270],
        "notes": [
            {
                "language": "nl",
                "note": "23,8 tot 2,6 miljoen jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1195],
        "id": 1209,
        "labels": [
            {"label": "neolithicum", "language": "nl", "type": "prefLabel"},
            {"label": "jonge steentijd", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1210, 1211, 1212, 1213],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Verwijst naar de laatste fase in de ontwikkeling van een"
                    " menselijke cultuur tijdens het stenen tijdperk. De fase kenmerkt"
                    " zich door het hoogwaardige stenen gereedschap dat werd"
                    " vervaardigd door middel van polijsten, de wijdverbreide"
                    " domesticatie van dieren en planten, de vestiging in permanente"
                    " nederzettingen en de introductie van aardewerk en geweven stof."
                    " Neolithische culturen ontstonden voor het eerst tijdens het"
                    " holoceen, ongeveer 9.000 v. Chr., in onze regio's vanaf ca. 5250"
                    " v.Chr. (tot 2000 v.Chr.). De artistieke voorwerpen zijn houten en"
                    " stenen huizen, religieuze monumenten, forten en fortificaties,"
                    " houtsnijwerk, schilderingen, textiel en aardewerk."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Van Dale groot woordenboek der Nederlandse taal. 14de editie,"
                    " Utrecht/Antwerpen, 2005. \n2) Nederlandse Art &amp; Architecture"
                    " Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                ),
                "type": "note",
            },
        ],
        "related": [1293],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 1236,
        "labels": [{"label": "nieuwe tijd", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [16, 17, 18],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "16de t.e.m. 18de eeuw. 16de t.e.m. 18de eeuw. De Nieuwe Tijd is"
                    " een opeenvolging van turbulente en rustige momenten. Tijdens de"
                    " 2de helft van de 16de eeuw kent men de periode van de"
                    " godsdiensttroebelen en de opstand tegen Spanje (Tachtigjarige"
                    " Oorlog). De clash tussen Spanje en Frankrijk wordt in de 2de"
                    " helft van de 17de eeuw in belangrijke mate uitgevochten in de"
                    " Zuidelijke Nederlanden en tekent het land"
                    " (Vauban-nederzettingen)."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "VIOE", "type": "note"},
        ],
        "related": [1296],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 1237,
        "labels": [{"label": "nieuwste tijd", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [19, 20, 21],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "19de eeuw en later. Tijdens de nieuwste tijd krijgen we in"
                    " Vlaanderen te maken met Napoleon, een tijdelijke unie met"
                    " Nederland en de uiteindelijke onafhankelijkheid van Belgi\xeb in"
                    " 1830. De 20ste eeuw wordt getekend door twee Wereldoorlogen, van"
                    " 1914 tot 1918 en van 1939 tot 1945."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "VIOE", "type": "note"},
        ],
        "related": [1296],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1264],
        "id": 1267,
        "labels": [{"label": "oligoceen", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "33,7 tot 23,8 miljoen jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1252],
        "id": 1254,
        "labels": [{"label": "ordovicium", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "495 tot 440 miljoen jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1264],
        "id": 1265,
        "labels": [{"label": "paleoceen", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "65 tot 53 miljoen jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1263],
        "id": 1264,
        "labels": [{"label": "paleogeen", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1265, 1266, 1267],
        "notes": [
            {
                "language": "nl",
                "note": "65 tot 23,8 miljoen jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1195],
        "id": 1199,
        "labels": [
            {"label": "paleolithicum", "language": "nl", "type": "prefLabel"},
            {"label": "oude steentijd", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1200, 1201, 1202, 1203],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "In de Lage Landen is het paleolithicum te dateren tussen 1 300 000"
                    " en 12 000 jaar geleden. De term verwijst naar de periode waaraan"
                    " het eerste gebruik van bewerkte stenen gereedschap in een bepaald"
                    " gebied wordt toegeschreven. Het tijdskader van deze periode kan"
                    " sterk uiteenlopen in verschillende delen van de wereld, maar het"
                    " wordt ongeveer 2.500.000 jaar geleden voor het eerst aangetroffen"
                    " bij mensachtigen. Vanaf de vroegste ontwikkeling van de mens tot"
                    " aan het einde van het Pleistoceen leeft de mens als"
                    " jager-verzamelaar."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                    " \n2) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [1272],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 1252,
        "labels": [{"label": "paleozo\xefcum", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1251],
        "narrower": [1253, 1254, 1255, 1256, 1257, 1258],
        "notes": [
            {
                "language": "nl",
                "note": "546 tot 203 miljoen jaar geleden",
                "type": "definition",
            }
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1252],
        "id": 1258,
        "labels": [{"label": "perm", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "298 tot 251 miljoen jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1271],
        "id": 1272,
        "labels": [{"label": "pleistoceen", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1273, 1280, 1285],
        "notes": [
            {
                "language": "nl",
                "note": "2,6 miljoen jaar geleden tot 10.000 jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [1199],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1268],
        "id": 1270,
        "labels": [{"label": "plioceen", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "5,3 tot 2,6 miljoen jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1289],
        "id": 1290,
        "labels": [{"label": "preboreaal", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "10.000 tot 9000 jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1229],
        "id": 1230,
        "labels": [
            {"label": "premerovingische periode", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "De premerovingische periode is te dateren tussen 440/450 en"
                    " 470/480."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Legoux R., P\xe9rin P. &amp; Vallet F. 2006: Chronologie"
                    " normalis\xe9e du mobilier fun\xe9raire m\xe9rovingien entre"
                    " Manche et Lorraine, in: Bulletin de Liaison de l'Association"
                    " fran\xe7aise d'Arch\xe9ologie m\xe9rovingienne. N\xb0 hors"
                    " s\xe9rie, St. Germain-en-Laye (bijgewerkte versie van 2004)."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1273],
        "id": 1274,
        "labels": [{"label": "pretigliaan", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "2,6 tot 2,45 miljoen jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 1271,
        "labels": [{"label": "quartiar", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1251],
        "narrower": [1272, 1288],
        "notes": [
            {
                "language": "nl",
                "note": "2,5 miljoen jaar geleden tot heden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 1223,
        "labels": [{"label": "Romeinse tijd", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1224, 1225, 1226],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Verwijst naar de periode, beschaving en artistieke stijl die zich"
                    " ontwikkelde toen het oude Rome aan macht won en de Griekse en"
                    " Etruskische invloed op het Apennijnse schiereiland verdrong en"
                    " kan algemeen gedateerd worden tussen ca. 750 v.Chr. en 476 n.Chr."
                    " (57 v.Chr. tot 406 n.Chr. in onze streken). De heerschappij en"
                    " invloed besloegen na verloop van tijd een groot deel van Europa,"
                    " Noord-Afrika, het Midden-Oosten en Klein-Azi\xeb. De Romeinse"
                    " invloed liet zich op vele vlakken gelden, onder meer in de"
                    " beeldhouwkunst, de schilderkunst, de architectuur, de techniek,"
                    " de taal, het wegennet, de wetgeving en op vele andere culturele"
                    " terreinen. De vroege Romeinse kunst en cultuur zijn afgeleid van"
                    " de Griekse kunst en cultuur, maar ontwikkelden zich geleidelijk"
                    " tot een eigen stijl, onder invloed van de verschillende"
                    " kunststijlen uit de verre streken die onder Romeins gezag"
                    " stonden."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                ),
                "type": "note",
            },
        ],
        "related": [1296],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1280],
        "id": 1284,
        "labels": [{"label": "saaliaan", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "370.000 tot 130.000 jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1252],
        "id": 1255,
        "labels": [{"label": "siluur", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "440 tot 410 miljoen jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 1195,
        "labels": [
            {"label": "steentijd", "language": "nl", "type": "prefLabel"},
            {"label": "prehistorie", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1199, 1204, 1209],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "De steentijd of prehistorie is (de studie van) de geschiedenis van"
                    " v\xf3\xf3r het begin van de (schriftelijk) overgeleverde"
                    " geschiedenis. Het is een fase in de technologische ontwikkeling"
                    " van mensachtigen en later de mens, of een fase van een"
                    " prehistorische menselijke cultuur die zich kenmerkt door de"
                    " ontwikkeling van stenen gereedschap en wapens. De steentijd wordt"
                    " doorgaans ingedeeld in drie perioden: het paleolithicum (de oude"
                    " steentijd),het mesolithicum(de middensteentijd)en het neolithicum"
                    " (de nieuwe steentijd), die zich van elkaar onderscheiden door de"
                    " toenemende verfijning in de vervaardiging en het gebruik van"
                    " werktuigen."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Van Dale groot woordenboek der Nederlandse taal. \n2)"
                    " Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a> \n'
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1295],
        "id": 1296,
        "labels": [{"label": "subatlanticum", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "2600 jaar geleden tot heden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [1197, 1218, 1223, 1227, 1236, 1237],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1292],
        "id": 1294,
        "labels": [{"label": "subboreaal", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "5000 tot 2600 jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [],
        "id": 1263,
        "labels": [{"label": "tertiair", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1251],
        "narrower": [1264, 1268],
        "notes": [
            {
                "language": "nl",
                "note": "65 tot 2,6 miljoen jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1273],
        "id": 1275,
        "labels": [{"label": "tigliaan", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "2,45 tot 1,8 miljoen jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1259],
        "id": 1260,
        "labels": [{"label": "trias", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "251 tot 203 miljoen jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [10],
        "id": 1020,
        "labels": [
            {"label": "tweede helft 10de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "10cd", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "951-1000", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [11],
        "id": 1022,
        "labels": [
            {"label": "tweede helft 11de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "11cd", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1051-1100", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [12],
        "id": 1024,
        "labels": [
            {"label": "tweede helft 12de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "12cd", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1151-1200", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [13],
        "id": 1028,
        "labels": [
            {"label": "tweede helft 13de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "13cd", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1029, 1030],
        "notes": [{"language": "nl", "note": "1251-1300", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [14],
        "id": 1034,
        "labels": [
            {"label": "tweede helft 14de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "14cd", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1035, 1036],
        "notes": [{"language": "nl", "note": "1351-1400", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [15],
        "id": 1040,
        "labels": [
            {"label": "tweede helft 15de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "15cd", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1041, 1042],
        "notes": [{"language": "nl", "note": "1451-1500", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [16],
        "id": 1046,
        "labels": [
            {"label": "tweede helft 16de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "16cd", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1047, 1048],
        "notes": [{"language": "nl", "note": "1551-1600", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [17],
        "id": 1052,
        "labels": [
            {"label": "tweede helft 17de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "17cd", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1053, 1054],
        "notes": [{"language": "nl", "note": "1651-1700", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [18],
        "id": 1058,
        "labels": [
            {"label": "tweede helft 18de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "18cd", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1059, 1060],
        "notes": [{"language": "nl", "note": "1751-1800", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [19],
        "id": 1064,
        "labels": [
            {"label": "tweede helft 19de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "19cd", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1065, 1066],
        "notes": [{"language": "nl", "note": "1851-1900", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [20],
        "id": 1072,
        "labels": [
            {"label": "tweede helft 20ste eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "20cd", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1073, 1074],
        "notes": [{"language": "nl", "note": "1946-2000", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [21],
        "id": 1078,
        "labels": [
            {"label": "tweede helft 21ste eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "21cd", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1079, 1080],
        "notes": [{"language": "nl", "note": "2051-2100", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [8],
        "id": 1016,
        "labels": [
            {"label": "tweede helft 8ste eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "8cd", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "751-800", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [9],
        "id": 1018,
        "labels": [
            {"label": "tweede helft 9de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "9cd", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "851-900", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1025],
        "id": 1027,
        "labels": [
            {"label": "tweede kwart 13de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "13b", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1226-1250", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1031],
        "id": 1033,
        "labels": [
            {"label": "tweede kwart 14de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "14b", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1326-1350", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1037],
        "id": 1039,
        "labels": [
            {"label": "tweede kwart 15de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "15b", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1426-1450", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1043],
        "id": 1045,
        "labels": [
            {"label": "tweede kwart 16de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "16b", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1526-1550", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1049],
        "id": 1051,
        "labels": [
            {"label": "tweede kwart 17de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "17b", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1626-1650", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1055],
        "id": 1057,
        "labels": [
            {"label": "tweede kwart 18de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "18b", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1726-1750", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1061],
        "id": 1063,
        "labels": [
            {"label": "tweede kwart 19de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "19b", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1826-1850", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1075],
        "id": 1077,
        "labels": [
            {"label": "tweede kwart 21ste eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "21b", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "2026-2050", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1072],
        "id": 1074,
        "labels": [{"label": "vanaf 1975", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1975-2000", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1028],
        "id": 1030,
        "labels": [
            {"label": "vierde kwart 13de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "13d", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1276-1300", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1034],
        "id": 1036,
        "labels": [
            {"label": "vierde kwart 14de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "14d", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1376-1400", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1040],
        "id": 1042,
        "labels": [
            {"label": "vierde kwart 15de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "15d", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1476-1500", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1046],
        "id": 1048,
        "labels": [
            {"label": "vierde kwart 16de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "16d", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1576-1600", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1052],
        "id": 1054,
        "labels": [
            {"label": "vierde kwart 17de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "17d", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1676-1700", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1058],
        "id": 1060,
        "labels": [
            {"label": "vierde kwart 18de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "18d", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1776-1800", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1064],
        "id": 1066,
        "labels": [
            {"label": "vierde kwart 19de eeuw", "language": "nl", "type": "prefLabel"},
            {"label": "19d", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1876-1900", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1078],
        "id": 1080,
        "labels": [
            {"label": "vierde kwart 21ste eeuw", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "2076-2100", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1227],
        "id": 1234,
        "labels": [
            {"label": "volle middeleeuwen", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [10, 11, 12],
        "notes": [
            {"language": "nl", "note": "10de t.em. 12de eeuw", "type": "definition"}
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1067],
        "id": 1068,
        "labels": [{"label": "v\xf3\xf3r WO I", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1901-1913", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1197],
        "id": 1198,
        "labels": [
            {"label": "vroege bronstijd", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Verwijst naar de vroegste fase van culturen uit de bronstijd"
                    " (2000/2100 - 1800/1750 v.Chr.), die zich verschillend hebben"
                    " ontwikkeld in verschillende regio's, op basis van chalcolithische"
                    " dan wel neolithische technieken. Onderscheidt zich voornamelijk"
                    " van de culturen uit de midden- en late bronstijd door"
                    " metaalassemblage en begrafenisriten. Kenmerkt zich deels door de"
                    " eerste experimenten met koperlegeringen voor de productie van"
                    " brons en door verbeteringen van stenen werktuigen en verscheidene"
                    " andere lokale culturele ontwikkelingen. Nederzettingen en"
                    " begraafplaatsen zijn voor deze vroege periode in Vlaanderen amper"
                    " met zekerheid aan te wijzen."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Van Dale groot woordenboek der Nederlandse taal. \n2)"
                    " Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                    " \n3) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1218],
        "id": 1219,
        "labels": [
            {"label": "vroege ijzertijd", "language": "nl", "type": "prefLabel"},
            {"label": "Halstatt-periode", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Verwijst naar de vroegste fase van de ijzertijd, toen de"
                    " specifieke functionele eigenschappen van ijzer voor het eerst"
                    " werden benut, door het te smeden, en het de plaats van brons"
                    " begon in te nemen bij de vervaardiging van gereedschappen en"
                    " wapens. Naast urnengraven komen ook brandrestengraven en"
                    " beenderpakgraven voor. Sociale status komt tot uiting in rijke"
                    " grafassemblages van ijzeren wapens en paardentuig. De periode"
                    " wordt voornamelijk gekenmerkt door contacten die vanuit de"
                    " Griekse steden aan de Middellandse Zee via het oosten van de"
                    " Alpen (o.a. Halstatt) gaan. Via de rivieren zijn de innovaties"
                    " uit Midden-Europa ongetwijfeld ook doorgedrongen tot westelijker"
                    " gelegen gebieden en de Lage Landen. Deze fase wordt gedateerd"
                    " tussen 800 en 600/450 v.Chr. afhankelijk van de regio."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                    " \n2) Bourgeois J., Cromb\xe9 P., De Mulder G. &amp; Rogge M."
                    " (red.), 2001, Een duik in het verleden. Schelde Maas en Rijn in"
                    " pre- en protohistorie, Zottegem. \n3) Hendriks J. 1994, Prisma"
                    " Archeologie in de Lage Landen, Utrecht."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1227],
        "id": 1228,
        "labels": [
            {"label": "vroege middeleeuwen", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1229, 1233],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Verwijst naar de perioden en stijlen in Europa vanaf de periode"
                    " der volksverhuizingen tot de romaanse periode, die grofweg de 5de"
                    " tot en met 9de eeuw beslaan."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://www.aat-ned.nl/">https://www.aat-ned.nl/</a>'
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1288],
        "id": 1289,
        "labels": [{"label": "vroegholoceen", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1290, 1291],
        "notes": [
            {
                "language": "nl",
                "note": "10.000 tot 8000 jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1229],
        "id": 1231,
        "labels": [
            {
                "label": "vroeg-Merovingische periode",
                "language": "nl",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "De vroeg-Merovingische periode is te dateren van 470/480 tot"
                    " 600/610."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "Legoux R., P\xe9rin P. &amp; Vallet F. 2006: Chronologie"
                    " normalis\xe9e du mobilier fun\xe9raire m\xe9rovingien entre"
                    " Manche et Lorraine, in: Bulletin de Liaison de l'Association"
                    " fran\xe7aise d'Arch\xe9ologie m\xe9rovingienne. N\xb0 hors"
                    " s\xe9rie, St. Germain-en-Laye (bijgewerkte versie van 2004)."
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1204],
        "id": 1205,
        "labels": [
            {"label": "vroegmesolithicum", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Het vroegmesolithicum wordt gekenmerkt door een grote homogeniteit"
                    " over uitgestrekte delen van Europa. Kenmerkend zijn een"
                    " vuursteentechnologie gericht op het produceren van klingen en een"
                    " vrij beperkt scala aan eenvoudige microlieten. De periode kan"
                    " gedateerd worden tussen 9500 en 7700 v.Chr."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Louwe Kooijmans L., van den Broecke P.W., Fokkens H. en van"
                    " Gijn A. (eds.), 2005, Nederland in de prehistorie, Amsterdam."
                    " \n2) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1209],
        "id": 1210,
        "labels": [
            {"label": "vroegneolithicum", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Voor de neolithisering van Europa zijn de ontwikkelingen in het"
                    " Nabije Oosten (de Vruchtbare Sikkel) van groot belang. Tijdens"
                    " het 10de millennium v.Chr. verschijnen daar de eerste"
                    " landbouwgemeenschappen, die zich ongeveer 2 millennia later zich"
                    " zullen begeven naar Europa waar ze in contact komen met lokale"
                    " jagers-verzamelaars. Dit is het startsein voor de neolithisatie"
                    " van Europa, een proces dat meerdere millennia zal bestrijken. De"
                    " sociale structuur van het vroegneolithicum bestaat uit tribale"
                    " gemeenschappen. Deze periode (5250 - 4800 v.Chr.) komt in onze"
                    " gebieden niet voor."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": "cursusmateriaal UGent (Prof. Ph. Cromb\xe9)",
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1199],
        "id": 1200,
        "labels": [
            {"label": "vroegpaleolithicum", "language": "nl", "type": "prefLabel"},
            {"label": "oudpaleolithicum", "language": "nl", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "Verwijst naar het eerste gedeelte van de paleolithische periode,"
                    " inclusief het grootste deel van het pleistoceen, van circa"
                    " 1.300.000 tot circa 300.000 jaar geleden. De vroegste fase van de"
                    " vroegpaleolithische periode kenmerkt zich door de vervaardiging"
                    " van eenvoudige stenen werktuigen door vroege mensachtigen. De"
                    " latere vroegpaleolithische traditie omvat de ontwikkeling in de"
                    " lithische industrie van choppers tot vuistbijlen, en is vernoemd"
                    " naar gevonden stenen werktuigen, en die veel voorkwam op het"
                    " oostelijk halfrond. De traditie wordt toegeschreven aan de homo"
                    " erectus, die waarschijnlijk ook werktuigen vervaardigde van hout"
                    " en beenderen."
                ),
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "1) Nederlandse Art &amp; Architecture Thesaurus, <a"
                    ' href="https://browser.aat-ned.nl/">https://browser.aat-ned.nl/</a>'
                    " \n2) VIOE"
                ),
                "type": "note",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1272],
        "id": 1273,
        "labels": [
            {"label": "vroegpleistoceen", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1274, 1275, 1276, 1277, 1278, 1279],
        "notes": [
            {
                "language": "nl",
                "note": "2,6 miljoen jaar geleden tot 850.000 jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1223],
        "id": 1224,
        "labels": [
            {"label": "Vroeg-Romeinse tijd", "language": "nl", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": (
                    "57 v.Chr.-69. Het begin van deze periode wordt gekenmerkt door de"
                    " verovering van onze gebieden door de Romeinen o.l.v. Caesar."
                ),
                "type": "definition",
            },
            {"language": "nl", "note": "VIOE", "type": "note"},
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1273],
        "id": 1277,
        "labels": [{"label": "waaliaan", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "1,5 tot 1,2 miljoen jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1285],
        "id": 1287,
        "labels": [{"label": "weichseliaan", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl",
                "note": "115.000 tot 10.000 jaar geleden",
                "type": "definition",
            },
            {
                "language": "nl",
                "note": (
                    "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen"
                ),
                "type": "historyNote",
            },
        ],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1067],
        "id": 1069,
        "labels": [{"label": "WO I", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1914-1918", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
    {
        "broader": [1067],
        "id": 1071,
        "labels": [{"label": "WO II", "language": "nl", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [{"language": "nl", "note": "1939-1945", "type": "definition"}],
        "related": [],
        "subordinate_arrays": [],
        "type": "concept",
    },
]



"""
Testdata cotaining periods

.. versionadded:: 0.4.4
"""


from skosprovider.providers import DictionaryProvider
from skosprovider.uri import UriPatternGenerator
from .periods_data import PERIODSDATA

periods = DictionaryProvider(
    {'id': 'PERIOD'},
    PERIODSDATA,
    uri_generator=UriPatternGenerator('https://id.erfgoed.net/thesauri/dateringen/%s')
)



from unittest.mock import MagicMock
from unittest.mock import Mock

import pytest
from skosprovider.registry import Registry

from atramhasis import skos


@pytest.fixture
def mock_request():
    mock = MagicMock()
    mock.db = MagicMock()
    return mock


@pytest.fixture
def mock_session():
    return MagicMock()


@pytest.fixture
def mock_manager(monkeypatch, mock_session):
    provider = MagicMock()

    def mock_get_all_providers(*_):
        return [provider]

    monkeypatch.setattr(
        'atramhasis.data.datamanagers.ProviderDataManager.get_all_providers',
        mock_get_all_providers,
    )


def test_create_registry_success(mock_request):
    registry = skos.create_registry(mock_request)
    assert isinstance(registry, Registry)
    # Should have at least 3 providers: AAT, TGN, and one from DB
    assert len(registry.providers) >= 2


def test_register_providers_from_db_adds_providers(
    mock_session, mock_manager, monkeypatch
):
    monkeypatch.setattr(
        'atramhasis.utils.db_provider_to_skosprovider',
        Mock(return_value=MagicMock(allowed_instance_scopes=False)),
    )
    registry = Registry()
    skos.register_providers_from_db(registry, mock_session)
    assert len(registry.providers) == 1


def test_register_providers_from_db_empty(monkeypatch, mock_session):
    class DummyManager:
        def __init__(self, session):
            pass

        def get_all_providers(self):
            return []

    monkeypatch.setattr(
        'atramhasis.data.datamanagers.ProviderDataManager', DummyManager
    )
    monkeypatch.setattr(
        'atramhasis.utils.db_provider_to_skosprovider',
        lambda db_provider: db_provider,
    )
    registry = Registry()
    skos.register_providers_from_db(registry, mock_session)
    assert len(registry.providers) == 0



# -*- coding: utf-8 -*-
from atramhasis.protected_resources import ProtectedResourceEvent
from atramhasis.protected_resources import ProtectedResourceException
from pyramid.events import subscriber


@subscriber(ProtectedResourceEvent)
def sample_impl(event):
    if event.uri.endswith("2"):
        referenced_in = ["urn:someobject", "https://test.test.org/object/2"]
        raise ProtectedResourceException(
            "resource {0} is still in use, preventing operation".format(event.uri),
            referenced_in,
        )



"""Add infer_concept_relations column.

Revision ID: cb568ec81000
Revises: 184f1bbcb916
Create Date: 2020-02-19 09:29:17.619082
"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "cb568ec81000"
down_revision = "184f1bbcb916"


def upgrade():
    op.add_column(
        "concept",
        sa.Column(
            "infer_concept_relations",
            sa.Boolean(),
            nullable=False,
            server_default="true",
        ),
    )


def downgrade():
    with op.batch_alter_table("concept") as batch_op:
        batch_op.drop_column("infer_concept_relations")



"""Languages for conceptschemes.

Revision ID: 2a38d364113b
Revises: 3ac8aca026fd
Create Date: 2015-11-19 15:03:45.587093

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "2a38d364113b"
down_revision = "3ac8aca026fd"


def upgrade():

    op.create_table(
        "conceptscheme_language",
        sa.Column("conceptscheme_id", sa.Integer(), nullable=False),
        sa.Column("language_id", sa.String(length=64), nullable=False),
        sa.ForeignKeyConstraint(
            ["conceptscheme_id"],
            ["conceptscheme.id"],
        ),
        sa.ForeignKeyConstraint(
            ["language_id"],
            ["language.id"],
        ),
        sa.PrimaryKeyConstraint("conceptscheme_id", "language_id"),
    )


def downgrade():

    op.drop_table("conceptscheme_language")



"""rename flemish vlaams


Revision ID: 0978347c16f9
Revises: 88214d86a9d1
Create Date: 2023-02-06 13:23:27.009952

"""

from alembic import op


# revision identifiers, used by Alembic.
revision = '0978347c16f9'
down_revision = '88214d86a9d1'

def upgrade():
    op.execute("UPDATE language SET name = 'Vlaams' WHERE id = 'vls'")
    
def downgrade():
    op.execute("UPDATE language SET name = 'Flemish' WHERE id = 'vls'")



import argparse
import itertools as it
import json
from datetime import date
from datetime import datetime
from unittest.mock import Mock

from pyramid.paster import get_appsettings
from pyramid.paster import setup_logging
from pyramid.util import DottedNameResolver
from skosprovider.registry import Registry
from skosprovider.uri import UriPatternGenerator
from skosprovider_sqlalchemy.models import ConceptScheme
from skosprovider_sqlalchemy.providers import SQLAlchemyProvider
from sqlalchemy.orm import Session

from atramhasis import utils
from atramhasis.data.models import ExpandStrategy
from atramhasis.data.models import IDGenerationStrategy
from atramhasis.data.models import Provider


def get_atramhasis_sqlalchemy_providers(session):
    licenses = [
        'https://creativecommons.org/licenses/by/4.0/',
        'https://data.vlaanderen.be/doc/licentie/modellicentie-gratis-hergebruik/v1.0'
    ]
    dataseturigenerator = UriPatternGenerator(
        'https://id.erfgoed.net/datasets/thesauri/%s'
    )
    return (
        SQLAlchemyProvider(
            {'id': 'TREES', 'conceptscheme_id': 1},
            session
        ),
        SQLAlchemyProvider(
            {'id': 'GEOGRAPHY', 'conceptscheme_id': 2},
            session
        ),
        SQLAlchemyProvider(
            {
                'id': 'STYLES',
                'conceptscheme_id': 3,
                'dataset': {
                    'uri': dataseturigenerator.generate(id='stijlen_en_culturen'),
                    'publisher': ['https://id.erfgoed.net/actoren/501'],
                    'created': [date(2008, 2, 14)],
                    'language': ['nl-BE'],
                    'license': licenses
                }

            },
            session,
            uri_generator=UriPatternGenerator(
                'https://id.erfgoed.net/thesauri/stijlen_en_culturen/%s'
            )
        ),
        SQLAlchemyProvider(
            {
                'id': 'MATERIALS',
                'conceptscheme_id': 4,
                'dataset': {
                    'uri': dataseturigenerator.generate(id='materialen'),
                    'publisher': ['https://id.erfgoed.net/actoren/501'],
                    'created': [date(2011, 3, 16)],
                    'language': ['nl-BE'],
                    'license': licenses
                }
            },
            session,
            uri_generator=UriPatternGenerator(
                'https://id.erfgoed.net/thesauri/materialen/%s'
            )
        ),
        SQLAlchemyProvider(
            {
                'id': 'EVENTTYPE',
                'conceptscheme_id': 5,
                'dataset': {
                    'uri': dataseturigenerator.generate(id='gebeurtenistypes'),
                    'publisher': ['https://id.erfgoed.net/actoren/501'],
                    'created': [date(2010, 8, 13)],
                    'language': ['nl-BE'],
                    'license': licenses
                }
            },
            session,
            uri_generator=UriPatternGenerator(
                'https://id.erfgoed.net/thesauri/gebeurtenistypes/%s'
            )
        ),
        SQLAlchemyProvider(
            {
                'id': 'HERITAGETYPE',
                'conceptscheme_id': 6,
                'dataset': {
                    'uri': dataseturigenerator.generate(id='erfgoedtypes'),
                    'publisher': ['https://id.erfgoed.net/actoren/501'],
                    'created': [date(2008, 2, 14)],
                    'language': ['nl-BE'],
                    'license': licenses
                }
            },
            session,
            uri_generator=UriPatternGenerator(
                'https://id.erfgoed.net/thesauri/erfgoedtypes/%s'
            )
        ),
        SQLAlchemyProvider(
            {
                'id': 'PERIOD',
                'conceptscheme_id': 7,
                'dataset': {
                    'uri': dataseturigenerator.generate(id='dateringen'),
                    'publisher': ['https://id.erfgoed.net/actoren/501'],
                    'created': [date(2008, 2, 14)],
                    'language': ['nl-BE'],
                    'license': licenses
                }
            },
            session,
            uri_generator=UriPatternGenerator('https://id.erfgoed.net/thesauri/dateringen/%s')
        ),
        SQLAlchemyProvider(
            {
                'id': 'SPECIES',
                'conceptscheme_id': 8,
                'dataset': {
                    'uri': dataseturigenerator.generate(id='soorten'),
                    'publisher': ['https://id.erfgoed.net/actoren/501'],
                    'created': [date(2011, 5, 23)],
                    'language': ['nl-BE', 'la'],
                    'license': licenses
                },
                'atramhasis.force_display_label_language': 'la'
            },
            session,
            uri_generator=UriPatternGenerator('https://id.erfgoed.net/thesauri/soorten/%s')
        ),
        SQLAlchemyProvider(
            {
                'id': 'BLUEBIRDS',
                'conceptscheme_id': 9,
                'atramhasis.id_generation_strategy': IDGenerationStrategy.MANUAL
            },
            session,
            uri_generator=UriPatternGenerator('https://id.bluebirds.org/%s')
        ),
    )


def json_serial(obj):
    if isinstance(obj, (datetime, date)):
        return obj.isoformat()
    raise TypeError(f"Type {obj} not serializable")


def migrate(skos_registry: Registry, session: Session):
    print("Starting migration of SQLAlchemyProvider in the registry...")
    for provider in it.chain(
        skos_registry.get_providers(),
        get_atramhasis_sqlalchemy_providers(session),
    ):
        if not isinstance(provider, SQLAlchemyProvider):
            continue

        if session.get(Provider, provider.get_vocabulary_id()) is not None:
            print(
                f"Provider with id {provider.get_vocabulary_id()} already exists. "
                f"Skipping creation of provider for conceptscheme "
                f"{provider.metadata.get('id') or ''}"
            )
            continue

        print(f"  Migrating provider {provider.concept_scheme.uri}")

        if provider.uri_generator:
            uri_pattern = getattr(provider.uri_generator, 'pattern', None)
        else:
            uri_pattern = None

        db_provider = Provider()
        if 'atramhasis.id_generation_strategy' in provider.metadata:
            # enum must be string to store as json.
            provider.metadata['atramhasis.id_generation_strategy'] = (
                provider.metadata['atramhasis.id_generation_strategy'].name
            )
        else:
            provider.metadata['atramhasis.id_generation_strategy'] = 'NUMERIC'
        db_provider.meta = json.loads(json.dumps(provider.metadata, default=json_serial))
        db_provider.expand_strategy = ExpandStrategy[provider.expand_strategy.upper()]
        db_provider.conceptscheme = session.get(ConceptScheme, provider.conceptscheme_id)
        db_provider.id = provider.get_vocabulary_id()
        db_provider.uri_pattern = uri_pattern
        if 'conceptscheme_id' in db_provider.meta:
            del db_provider.meta['conceptscheme_id']

        session.add(db_provider)
    print("Migration finished.")


def main():
    parser = argparse.ArgumentParser(
        description="Migrate SQLAlchemyProviders from a skosregistry to the database.",
    )
    parser.add_argument('settings_file',
                        help="<The location of the settings file>#<app-name>")
    args = parser.parse_args()

    config_uri = args.settings_file
    setup_logging(config_uri)
    settings = get_appsettings(config_uri)

    resolver = DottedNameResolver()
    skos_registry_factory = resolver.resolve(settings['skosprovider.skosregistry_factory'])

    with utils.db_session(settings) as session:
        if settings['skosprovider.skosregistry_location'] == 'registry':
            skos_registry = skos_registry_factory()
        else:
            skos_registry = skos_registry_factory(Mock(db=session))
        migrate(skos_registry, session)


if __name__ == '__main__':  # pragma: no cover
    main()
